@@ -18,9 +18,12 @@
 #
 #=============================================================================
 
-package Term::CLI  0.052002 {
+package Term::CLI  0.052003 {
+
+use 5.014;
+use strict;
+use warnings;
 
-use Term::CLI::PerlFeatures;
 use Text::ParseWords 3.29 qw( parse_line );
 use Term::CLI::ReadLine;
 use FindBin 1.50;
@@ -467,7 +470,7 @@ Term::CLI - CLI interpreter based on Term::ReadLine
 
 =head1 VERSION
 
-version 0.052002
+version 0.052003
 
 =head1 SYNOPSIS
 
