@@ -18,9 +18,12 @@
 #
 #=============================================================================
 
-package Term::CLI::Argument  0.052002 {
+package Term::CLI::Argument  0.052003 {
+
+use 5.014;
+use strict;
+use warnings;
 
-use Term::CLI::PerlFeatures;
 use Moo 1.000001;
 
 use Term::CLI::L10N;
@@ -89,7 +92,7 @@ Term::CLI::Argument - generic parent class for arguments in Term::CLI
 
 =head1 VERSION
 
-version 0.052002
+version 0.052003
 
 =head1 SYNOPSIS
 
