@@ -18,9 +18,12 @@
 #
 #=============================================================================
 
-package Term::CLI::Argument::Enum  0.052002 {
+package Term::CLI::Argument::Enum  0.052003 {
+
+use 5.014;
+use strict;
+use warnings;
 
-use Term::CLI::PerlFeatures;
 use Term::CLI::L10N;
 
 use Types::Standard 1.000005 qw(
@@ -87,7 +90,7 @@ Term::CLI::Argument::Enum - class for "enum" string arguments in Term::CLI
 
 =head1 VERSION
 
-version 0.052002
+version 0.052003
 
 =head1 SYNOPSIS
 
