@@ -18,9 +18,12 @@
 #
 #=============================================================================
 
-package Term::CLI::Argument::Filename  0.052002 {
+package Term::CLI::Argument::Filename  0.052003 {
+
+use 5.014;
+use strict;
+use warnings;
 
-use Term::CLI::PerlFeatures;
 use Moo 1.000001;
 use namespace::clean 0.25;
 
@@ -56,7 +59,7 @@ Term::CLI::Argument::Filename - class for file name arguments in Term::CLI
 
 =head1 VERSION
 
-version 0.052002
+version 0.052003
 
 =head1 SYNOPSIS
 
