@@ -18,9 +18,12 @@
 #
 #=============================================================================
 
-package Term::CLI::Argument::Number  0.052002 {
+package Term::CLI::Argument::Number  0.052003 {
+
+use 5.014;
+use strict;
+use warnings;
 
-use Term::CLI::PerlFeatures;
 use Term::CLI::L10N;
 
 use Moo 1.000001;
@@ -82,7 +85,7 @@ Term::CLI::Argument::Number - base class for numerical arguments in Term::CLI
 
 =head1 VERSION
 
-version 0.052002
+version 0.052003
 
 =head1 SYNOPSIS
 
