@@ -18,9 +18,12 @@
 #
 #=============================================================================
 
-package Term::CLI::Argument::Number::Float  0.052002 {
+package Term::CLI::Argument::Number::Float  0.052003 {
+
+use 5.014;
+use strict;
+use warnings;
 
-use Term::CLI::PerlFeatures;
 use Scalar::Util 1.38 qw( looks_like_number );
 
 use Moo 1.000001;
@@ -49,7 +52,7 @@ Term::CLI::Argument::Number::Float - class for floating point arguments in Term:
 
 =head1 VERSION
 
-version 0.052002
+version 0.052003
 
 =head1 SYNOPSIS
 
