@@ -18,9 +18,11 @@
 #
 #=============================================================================
 
-package Term::CLI::Argument::String  0.052002 {
+package Term::CLI::Argument::String  0.052003 {
 
-use Term::CLI::PerlFeatures;
+use 5.014;
+use strict;
+use warnings;
 
 use Term::CLI::L10N;
 
@@ -70,7 +72,7 @@ Term::CLI::Argument::String - class for basic string arguments in Term::CLI
 
 =head1 VERSION
 
-version 0.052002
+version 0.052003
 
 =head1 SYNOPSIS
 
