@@ -18,9 +18,12 @@
 #
 #=============================================================================
 
-package Term::CLI::Base  0.052002 {
+package Term::CLI::Base  0.052003 {
+
+use 5.014;
+use strict;
+use warnings;
 
-use Term::CLI::PerlFeatures;
 use Term::CLI::ReadLine;
 
 use Types::Standard 1.000005 qw(
@@ -60,7 +63,7 @@ Term::CLI::Base - generic base class for Term::CLI classes
 
 =head1 VERSION
 
-version 0.052002
+version 0.052003
 
 =head1 SYNOPSIS
 
