@@ -18,9 +18,12 @@
 #
 #=============================================================================
 
-package Term::CLI::Command  0.052002 {
+package Term::CLI::Command  0.052003 {
+
+use 5.014;
+use strict;
+use warnings;
 
-use Term::CLI::PerlFeatures;
 use List::Util 1.38 qw( first min );
 use Getopt::Long 2.42 qw( GetOptionsFromArray );
 use Types::Standard 1.000005 qw(
@@ -326,7 +329,7 @@ Term::CLI::Command - Class for (sub-)commands in Term::CLI
 
 =head1 VERSION
 
-version 0.052002
+version 0.052003
 
 =head1 SYNOPSIS
 
