@@ -18,9 +18,12 @@
 #
 #=============================================================================
 
-package Term::CLI::Command::Help  0.052002 {
+package Term::CLI::Command::Help  0.052003 {
+
+use 5.014;
+use strict;
+use warnings;
 
-use Term::CLI::PerlFeatures;
 use Pod::Text::Termcap 2.08;
 use List::Util 1.38 qw( first min );
 use File::Which 1.09;
@@ -421,7 +424,7 @@ Term::CLI::Command::Help - A generic 'help' command for Term::CLI
 
 =head1 VERSION
 
-version 0.052002
+version 0.052003
 
 =head1 SYNOPSIS
 
