@@ -18,9 +18,12 @@
 #
 #=============================================================================
 
-package Term::CLI::Element  0.052002 {
+package Term::CLI::Element  0.052003 {
+
+use 5.014;
+use strict;
+use warnings;
 
-use Term::CLI::PerlFeatures;
 use Term::CLI::ReadLine;
 
 use Types::Standard 1.000005 qw( Str );
@@ -46,7 +49,7 @@ Term::CLI::Element - generic parent class for elements in Term::CLI
 
 =head1 VERSION
 
-version 0.052002
+version 0.052003
 
 =head1 SYNOPSIS
 
