@@ -16,9 +16,11 @@
 #
 #=============================================================================
 
-package Term::CLI::L10N  0.052002 {
+package Term::CLI::L10N  0.052003 {
 
-use Term::CLI::PerlFeatures;
+use 5.014;
+use strict;
+use warnings;
 
 use parent 0.228 qw( Locale::Maketext Exporter );
 
@@ -71,7 +73,7 @@ Term::CLI::L10N - localizations for Term::CLI
 
 =head1 VERSION
 
-version 0.052002
+version 0.052003
 
 =head1 SYNOPSIS
 
