@@ -15,9 +15,11 @@
 #
 #=============================================================================
 
-package Term::CLI::L10N::en  0.052002 {
+package Term::CLI::L10N::en  0.052003 {
 
-use Term::CLI::PerlFeatures;
+use 5.014;
+use strict;
+use warnings;
 
 use parent 0.228 qw( Term::CLI::L10N );
 
@@ -39,7 +41,7 @@ Term::CLI::L10N::en - English localizations for Term::CLI
 
 =head1 VERSION
 
-version 0.052002
+version 0.052003
 
 =head1 SYNOPSIS
 
