@@ -17,9 +17,11 @@
 
 package Term::CLI::L10N::nl;
 
-our $VERSION = 0.052002;
+use 5.014;
+use strict;
+use warnings;
 
-use Term::CLI::PerlFeatures;
+our $VERSION = 0.052003;
 
 use parent 0.228 qw( Term::CLI::L10N );
 
@@ -299,7 +301,7 @@ Term::CLI::L10N::nl - Dutch localizations for Term::CLI
 
 =head1 VERSION
 
-version 0.052002
+version 0.052003
 
 =head1 SYNOPSIS
 
