@@ -18,9 +18,11 @@
 #
 #=============================================================================
 
-package Term::CLI::ReadLine  0.052002 {
+package Term::CLI::ReadLine  0.052003 {
 
-use Term::CLI::PerlFeatures;
+use 5.014;
+use strict;
+use warnings;
 
 use Carp qw( confess );
 
@@ -80,7 +82,7 @@ Term::CLI::ReadLine - maintain a single Term::ReadLine object
 
 =head1 VERSION
 
-version 0.052002
+version 0.052003
 
 =head1 SYNOPSIS
 
