@@ -18,9 +18,11 @@
 #
 #=============================================================================
 
-package Term::CLI::Role::ArgumentSet  0.052002 {
+package Term::CLI::Role::ArgumentSet  0.052003 {
 
-use Term::CLI::PerlFeatures;
+use 5.014;
+use strict;
+use warnings;
 
 use Types::Standard 1.000005 qw(
     ArrayRef
@@ -96,7 +98,7 @@ Term::CLI::Role::ArgumentSet - Role for (sub-)commands in Term::CLI
 
 =head1 VERSION
 
-version 0.052002
+version 0.052003
 
 =head1 SYNOPSIS
 
