@@ -18,9 +18,12 @@
 #
 #=============================================================================
 
-package Term::CLI::Role::CommandSet  0.052002 {
+package Term::CLI::Role::CommandSet  0.052003 {
+
+use 5.014;
+use strict;
+use warnings;
 
-use Term::CLI::PerlFeatures;
 use Term::CLI::L10N;
 
 use Types::Standard 1.000005 qw(
@@ -172,7 +175,7 @@ Term::CLI::Role::CommandSet - Role for (sub-)commands in Term::CLI
 
 =head1 VERSION
 
-version 0.052002
+version 0.052003
 
 =head1 SYNOPSIS
 
