@@ -1,6 +1,7 @@
-#!/usr/bin/perl
+#!/usr/bin/env perl
+use 5.014;
+use warnings;
 
-use Modern::Perl;
 use FindBin;
 use lib ("$FindBin::Bin/../lib");
 
